@@ -1,20 +1,10 @@
 import base64
-import hashlib
-import hmac
-import json
-import datetime
-import nltk
-import ssl
 from typing import Any, Dict, List, Optional, Union
 from marqo.index import Index
-from marqo.enums import Devices
 from marqo.config import Config
 from marqo._httprequests import HttpRequests
-from marqo.errors import MarqoError
-from marqo.neural_search import neural_search, index_meta_cache
-import urllib3
 from marqo import utils, enums
-
+from marqo import errors
 
 class Client:
     """
@@ -34,8 +24,6 @@ class Client:
         url:
             The url to the S2Search API (ex: http://localhost:9200)
         """
-        self._ensure_nltk_setup()
-
         self.main_user = main_user
         self.main_password = main_password
         if (main_user is not None) and (main_password is not None):
@@ -44,72 +32,50 @@ class Client:
             self.url = url
         self.config = Config(self.url, indexing_device=indexing_device, search_device=search_device)
         self.http = HttpRequests(self.config)
-        index_meta_cache.populate_cache(config=self.config)
-        if not self.config.cluster_is_s2search:
-            self._turn_off_auto_create_index()
-
-    def _turn_off_auto_create_index(self):
-        """turns off auto creation of indices. To be run in client instantiation"""
-        self.http.put(
-            path="_cluster/settings",
-            body={
-                "persistent": {"action.auto_create_index": "false"}
-            })
-
 
     def create_index(
         self, index_name: str,
         treat_urls_and_pointers_as_images=False, model=None,
         normalize_embeddings=True,
         sentences_per_chunk=2,
-        sentence_overlap=0
+        sentence_overlap=0,
+        image_preprocessing_method=None,
     ) -> Dict[str, Any]:
-        """Create an index.
+        """
 
-        Parameters
-        ----------
-        index_name: str
-            name of the index.
+        Args:
+            index_name:
+            treat_urls_and_pointers_as_images:
+            model:
+            normalize_embeddings:
+            sentences_per_chunk:
+            sentence_overlap:
+            image_preprocessing_method:
 
+        Returns:
 
-        Returns
-        -------
-        task:
-            Name of the index
-
-        Raises
-        ------
-        s2SearchApiError
-            An error containing details about why marqo can't process your request. marqo error codes are described here: https://docs.marqo.com/errors/#marqo-errors
         """
         return Index.create(
             config=self.config, index_name=index_name,
             treat_urls_and_pointers_as_images=treat_urls_and_pointers_as_images,
             model=model, normalize_embeddings=normalize_embeddings,
-            sentences_per_chunk=sentences_per_chunk, sentence_overlap=sentence_overlap
+            sentences_per_chunk=sentences_per_chunk, sentence_overlap=sentence_overlap,
+            image_preprocessing_method=image_preprocessing_method
         )
 
     def delete_index(self, index_name: str) -> Dict[str, Any]:
         """Deletes an index
 
-        Parameters
-        ----------
-        index_name:
-            UID of the index.
+        Args:
+            index_name: name of the index
 
-        Returns
-        -------
-        task:
-            Dictionary containing a task to track the informations about the progress of an asynchronous process.
-            https://docs.marqo.com/reference/api/tasks.html#get-one-task
-
-        Raises
-        ------
-        s2SearchApiError
-            An error containing details about why marqo can't process your request. marqo error codes are described here: https://docs.marqo.com/errors/#marqo-errors
+        Returns:
+            response body about the result of the delete request
         """
-
-        return neural_search.delete_index(config=self.config, index_name=index_name)
+        try:
+            res = self.http.delete(path=f"indexes/{index_name}")
+        except errors.MarqoWebError as e:
+            return e.message
 
     def get_index(self, index_name: str) -> Index:
         """Get the index.
@@ -132,7 +98,8 @@ class Client:
         """
         ix = Index(self.config, index_name)
         # verify it exists
-        self.http.get(path=index_name)
+        # maybe delete - use stats end point for now
+        self.http.get(path=f"indexes/{index_name}/stats")
         return ix
 
     def index(self, index_name: str) -> Index:
@@ -188,9 +155,3 @@ class Client:
         data: bytes
     ) -> str:
         return base64.urlsafe_b64encode(data).decode('utf-8').replace('=','')
-
-    def _ensure_nltk_setup(self):
-        try:
-            nltk.data.find('tokenizers/punkt')
-        except LookupError:
-            nltk.download('punkt')
